<?php

App::uses('BuzzVouchersAppModel', 'BuzzVouchers.Model');

class VoucherActivity extends BuzzVouchersAppModel {

/**
 * Behaviors
 *
 * @var array
 */
	public $actsAs = array(
		'BuzzTranslate.Translatable'
	);

/**
 * Has many associations
 *
 * @var array
 */
	public $hasMany = array(
		'GiftVoucher' => array(
			'className' => 'BuzzVouchers.GiftVoucher'
		)
	);

/**
 * Validation rules
 *
 * @var array
 */
	public $validate = array(
		'name' => array(
			'required' => array(
				'rule' => 'notEmpty',
				'message' => 'validate.required'
			),
			'max' => array(
				'rule' => array('maxLength', 150),
				'message' => 'validate.maxLength150'
			)
		)
	);

/**
 * Constructor
 */
	public function __construct($id = false, $table = null, $ds = null) {
		parent::__construct($id, $table, $ds);

		if (Configure::check('BuzzVouchers.routes.activities') === true) {
			$this->addBehaviour('Routable.Routable', Configure::read('BuzzVouchers.routes.activities'));
		}
	}

/**
 * Get all visible listed voucher activities.
 *
 * @return array
 */
	public function getListed() {
		$params = array(
			'conditions' => array(
				'VoucherActivity.is_active' => true,
				'VoucherActivity.is_removed' => false
			),
			'order' => array(
				'VoucherActivity.sequence' => 'ASC',
				'VoucherActivity.created' => 'ASC'
			)
		);
		return $this->find('all', $params);
	}

/**
 * Returns a translated list of listed voucher activities.
 *
 * @return array
 */
	public function listListed() {
		$results = $this->getListed();

		$data = [];
		foreach ($results as $result) {
			$data[$result['VoucherActivity']['id']] = TranslateUtil::translate($result, 'VoucherActivity.name');
		}

		return $data;
	}

/**
 * Checks if there is only one available listed activity for the site, if
 * there's only one activity it will return the activity ID, otherwise it
 * returns false
 *
 * @return bool|int
 */
	public function onlyAvailableActivity() {
		// Get the listed activities
		$data = $this->getListed();
		return count($data) === 1 && !empty($data[0]['VoucherActivity']['id']) ? $data[0]['VoucherActivity']['id'] : false;
	}

/**
 * Returns a voucher activity and its vouchers
 *
 * @param int $voucherActivityId Voucher activity ID
 * @return array|bool
 */
	public function getPurchasableVoucherActivity($voucherActivityId) {
		// Want to make sure all returned vouchers have an API reference set.
		$params = array(
			'contain' => array(
				'GiftVoucher' => array(
					'Image',
					'conditions' => array(
						'GiftVoucher.is_active' => true,
						'OR' => array(
							'GiftVoucher.api_reference <>' => null,
							'GiftVoucher.api_reference <>' => ''
						)
					)
				)
			)
		);
		// Get the activity and its vouchers.
		$data = $this->readForView($voucherActivityId, $params);
		return !empty($data) && !empty($data['GiftVoucher']) ? $data : false;
	}

}
